@@ -31,6 +31,8 @@ static const char description[] = I18N_NOOP("Mahjongg Solitaire by KDE");
 
 int main(int argc, char ** argv)
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kmahjongg");
